pub struct Payload {
pub chain_id: String,
pub tx_type: i32,
pub tx_id: String,
pub timestamp: i64,
pub expiration_time: i64,
pub contract_name: String,
pub method: String,
pub parameters: Vec<KeyValuePair>,
pub sequence: u64,
pub limit: Option<Limit>,
}Expand description
transaction payload
Fields
chain_id: Stringblockchain identifier
tx_type: i32transaction type
tx_id: Stringtransaction id set by sender, should be unique
timestamp: i64transaction timestamp, in unix timestamp format, seconds
expiration_time: i64expiration timestamp in unix timestamp format after that the transaction is invalid if it is not included in block yet
contract_name: Stringsmart contract name
method: Stringinvoke method
parameters: Vec<KeyValuePair>invoke parameters in k-v format
sequence: u64sequence number, default is 0
limit: Option<Limit>transaction limitation
Implementations