#[repr(i32)]pub enum WalEntryType {
TimeoutEntry = 0,
ProposalEntry = 1,
VoteEntry = 2,
ProposalVoteEntry = 3,
}Expand description
WalEntryType represents different types of entries in Wal
Variants
Implementations
Sourceimpl WalEntryType
impl WalEntryType
Sourceimpl WalEntryType
impl WalEntryType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.